package com.ruoyi.frequency.bondamounrecord.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.bondamounrecord.entity.BondAmountRecord;
import com.ruoyi.vo.UserVo;

import java.math.BigDecimal;
import java.util.List;

/**
 * 缴纳保证金Service接口
 * 
 * @author liwenlong
 * @date 2023-10-31
 */
public interface BondAmountRecordService extends IService<BondAmountRecord>
{
    /**
     * 查询缴纳保证金
     * 
     * @param id 缴纳保证金主键
     * @return 缴纳保证金
     */
    public BondAmountRecord selectBondAmountRecordById(Long id);

    /**
     * 查询缴纳保证金列表
     * 
     * @param bondAmountRecord 缴纳保证金
     * @return 缴纳保证金集合
     */
    public List<BondAmountRecord> selectBondAmountRecordList(BondAmountRecord bondAmountRecord);

    /**
     * 新增缴纳保证金
     * 
     * @param bondAmountRecord 缴纳保证金
     * @return 结果
     */
    public int insertBondAmountRecord(BondAmountRecord bondAmountRecord);

    /**
     * 修改缴纳保证金
     * 
     * @param bondAmountRecord 缴纳保证金
     * @return 结果
     */
    public int updateBondAmountRecord(BondAmountRecord bondAmountRecord);

    /**
     * 批量删除缴纳保证金
     * 
     * @param ids 需要删除的缴纳保证金主键集合
     * @return 结果
     */
    public int deleteBondAmountRecordByIds(Long[] ids,Integer delFalg);

    /**
     *
     * @param userVo
     * @param type 1 提现 2 提现返还
     * @param withDrawlRecordId
     * @param amount
     * @param status
     */
    void updateBond(UserVo userVo,Long objectId, Integer type, Long withDrawlRecordId, BigDecimal amount, Integer status);
}
